/*!
 * TimeSlots Booking Calendar v3.0
 * http://www.phpjabbers.com/time-slots-booking-calendar/
 * 
 * Copyright 2014, StivaSoft Ltd.
 * 
 * Date: Wed Nov 27 17:17:20 2013 +0200
 */
(function (window, undefined) {
	"use strict";
	var document = window.document,
		validate = (pjQ.$.fn.validate !== undefined),
		routes = [
			{pattern: /^#!\/Login$/, eventName: "loadLogin"}
		];
	
	function log() {
		if (window.console && window.console.log) {
			for (var x in arguments) {
				if (arguments.hasOwnProperty(x)) {
					window.console.log(arguments[x]);
				}
			}
		}
	}
	
	function assert() {
		if (window && window.console && window.console.assert) {
			window.console.assert.apply(window.console, arguments);
		}
	}
	
	function hashBang(value) {
		if (value !== undefined && value.match(/^#!\//) !== null) {
			if (window.location.hash == value) {
				return false;
			}
			window.location.hash = value;
			return true;
		}
		
		return false;
	}
	
	function onHashChange() {
		var i, iCnt, m;
		for (i = 0, iCnt = routes.length; i < iCnt; i++) {
			m = unescape(window.location.hash).match(routes[i].pattern);
			if (m !== null) {
				pjQ.$(window).trigger(routes[i].eventName, m.slice(1));
				break;
			}
		}
		if (m === null) {
			pjQ.$(window).trigger("loadRouter");
		}
	}
	
	pjQ.$(window).on("hashchange", function (e) {
    	onHashChange.call(null);
    });
	
	if (!Date.prototype.toISOString) {
		(function(){
			function pad(number) {
				var r = String(number);
				if (r.length === 1) {
					r = '0' + r;
				}
				return r;
			}

			Date.prototype.toISOString = function() {
				return this.getUTCFullYear()
				+ '-' + pad(this.getUTCMonth() + 1)
				+ '-' + pad(this.getUTCDate())
				+ 'T' + pad(this.getUTCHours())
				+ ':' + pad(this.getUTCMinutes())
				+ ':' + pad(this.getUTCSeconds())
				+ '.' + String((this.getUTCMilliseconds()/1000).toFixed(3)).slice(2, 5)
				+ 'Z';
			};
		}());
	}
	
	function TSBCalendar(options) {
		if (!(this instanceof TSBCalendar)) {
			return new TSBCalendar(options);
		}
		
		this.reset.call(this);
		this.init.call(this, options);
		
		return this;
	}
	
	// --- Public methods/members
	TSBCalendar.prototype = {
		reset: function () {
			this.$container = null;
			this.container = null;
			this.view = null;
			this.date = new Date().toISOString().slice(0, 10);
			this.booking_uuid = null;
			this.options = {};
			
			return this;
		},
		init: function(opts) {
			var self = this;
			this.options = opts;

			this.container = document.getElementById("tsContainer_" + this.options.cid);
			if (this.container) {
				this.$container = pjQ.$(this.container);
			}
			
			//Custom events
			pjQ.$(window).on("loadLogin", this.container, function (e) {
				self.loadLogin.call(self);
			});
			
			if (window.location.hash.length === 0) {
				pjQ.$(window).trigger("loadLogin");
			} else {
				onHashChange.call(null);
			}
			
			return this;
		},
		disableButtons: function () {
			this.$container.find(".tsSelectorButton").attr("disabled", "disabled");

			return this;
		},
		enableButtons: function () {
			this.$container.find(".tsSelectorButton").removeAttr("disabled");

			return this;
		},
		errorHandler: function (msg) {
			this.$container.find(".tsSelectorNotice:first").html(msg).show();
			
			return this;
		},
		loadLogin: function () {
			var self = this;
			this.disableButtons.call(this);
			pjQ.$.get([this.options.folder, "index.php?controller=pjFrontEnd&action=pjActionLogin"].join(""), {
				"cid": this.options.cid,
				"locale": this.options.locale,
				"layout": this.options.layout
			}).done(function (data) {
				self.$container.html(data);

				self.view = 'pjActionLogin';
				
				if (validate) {
					pjQ.jQuery.validator.addClassRules("tsRequired", {
						required: true
					});
					pjQ.jQuery.validator.addClassRules("tsEmail", {
						email: true
					});
					self.$container.find(".tsSelectorLoginForm").validate({
						onkeyup: false,
						onclick: false,
						onfocusout: false,
						errorClass: "tsError",
						validClass: "tsValid",
						wrapper: "em",
						errorPlacement: function (error, element) {
							error.insertAfter(element.closest(".tsRowControl"));
						},
						submitHandler: function (form) {
							self.disableButtons.call(self);
							var $form = pjQ.$(form);
							pjQ.$.post([self.options.folder, "index.php?controller=pjFrontEnd&action=pjActionLogin&cid=", self.options.cid].join(""), $form.serialize()).done(function (data) {
								self.errorHandler.call(self, data.text);
								if (data.status == "OK") {
								} else if (data.status == "ERR") {
									self.enableButtons.call(self);
								}
							}).fail(function () {
								self.enableButtons.call(self);
							});
							return false;
						}
					});
				}
				
			}).fail(function () {
				self.enableButtons.call(self);
			});
			return this;
		}
	};
	
	// expose
	window.TSBCalendar = TSBCalendar;
})(window);